#! /usr/bin/python3
import numpy as np
from scipy.integrate import odeint
import matplotlib.pyplot as plt

N = 38000000                #Population
I0, R0 = 100, 0               #Initial number of Infected and Recovered
S0 = N - I0 - R0            #Susceptible
#beta= 1/5.2                 #contact rate
gamma = 1/14                #recovery rate

def beta(t):
    return 1/6.2 if t < 150 else 1/2.7

t = np.linspace(0, 360)
def deriv(y, t, N, beta, gamma):
    S, I, R = y
    dSdt = -beta(t) * S * I / N
    dIdt = beta(t) * S * I / N - gamma * I
    dRdt = gamma * I
    return dSdt, dIdt, dRdt

y0 = S0, I0, R0             #Initial vector
result = odeint(deriv, y0, t, args=(N, beta, gamma))
S, I, R = result.T

#Plot
fig = plt.figure(facecolor='w')
ax = fig.add_subplot(111, facecolor='#dddddd', axisbelow=True)
ax.plot(t, S, 'b', alpha=0.5, lw=2, label='Susceptible')
ax.plot(t, I, 'r', alpha=0.5, lw=2, label='Infected')
ax.plot(t, R, 'g', alpha=0.5, lw=2, label='Recovered')
ax.set_xlabel('Time /days')
ax.set_ylabel('Number')
ax.set_ylim(0, N)
ax.grid(b=True, which='major', c='w', lw=2, ls='-')
ax.yaxis.set_tick_params(length=0)
ax.xaxis.set_tick_params(length=0)
legend = ax.legend()
legend.get_frame().set_alpha(0.5)
for spine in ('top', 'right', 'bottom', 'left'):
    ax.spines[spine].set_visible(False)
plt.show()
